package com.isu.gaswellwatch.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.isu.gaswellwatch.annotation.OperationLog;
import com.isu.gaswellwatch.dto.GasWellCreateRequest;
import com.isu.gaswellwatch.dto.GasWellEditRequest;
import com.isu.gaswellwatch.entity.Response;
import com.isu.gaswellwatch.enums.LogType;
import com.isu.gaswellwatch.service.GasWellService;
import com.isu.gaswellwatch.vo.GasWellVO;
import jakarta.validation.Valid;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

/**
 * 气井管理
 *
 * @author scwsl
 * @date 2024-11-17
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/gasWell")
public class GasWellController {

    private final GasWellService gasWellService;

    /**
     * 查询气井列表
     */
    @GetMapping(value = "/page")
    public Response<Page<GasWellVO>> page(@RequestParam(defaultValue = "1") Integer currentPage,
                                          @RequestParam(defaultValue = "10") Integer pageSize,
                                          @RequestParam(required = false) String name,
                                          @RequestParam Long blockId) {
        return Response.succeed(this.gasWellService.pageForQuery(currentPage, pageSize, name, blockId));
    }

    /**
     * 获取气井详细信息
     */
    @GetMapping(value = "/getGasWell")
    public Response<GasWellVO> getGasWell(@RequestParam Long id) {
        return Response.succeed(this.gasWellService.selectGasWellById(id));
    }

    /**
     * 新增气井
     */
    @PostMapping(value = "/add")
    @OperationLog(description = "新增气井", type = LogType.ADD)
    public Response<String> add(@RequestBody @Valid GasWellCreateRequest gasWellCreateRequest) {
        this.gasWellService.insertGasWell(gasWellCreateRequest);
        return Response.succeed();
    }

    /**
     * 修改气井
     */
    @PostMapping("/edit")
    @OperationLog(description = "修改气井", type = LogType.UPDATE)
    public Response<String> edit(@RequestBody GasWellEditRequest gasWellEditRequest) {
        this.gasWellService.updateGasWell(gasWellEditRequest);
        return Response.succeed();
    }

    /**
     * 删除气井
     */
    @GetMapping("/delete")
    @OperationLog(description = "删除气井", type = LogType.DELETE)
    public Response<String> delete(@RequestParam Long id) {
        this.gasWellService.deleteGasWellById(id);
        return Response.succeed();
    }


}
